LifecycleRunner

Struct LifecycleRunner 

pub struct LifecycleRunner { /* private fields */ }
Ordered lifecycle hook runner.

Implementations

Source

impl LifecycleRunner

pub fn new() -> LifecycleRunner

Creates an empty lifecycle runner.

pub fn hook<H>(self, hook: H) -> LifecycleRunner
where H: LifecycleHook,

Registers a lifecycle hook.

pub async fn startup(&self) -> Result<(), NidusError>

Runs startup hooks in registration order.

pub async fn shutdown(&self) -> Result<(), NidusError>

Runs shutdown hooks in reverse registration order.

Every hook is attempted even when an earlier hook fails. The first failure in shutdown order is returned after the remaining hooks run.