pub struct LifecycleRunner { /* private fields */ }Expand description
Ordered lifecycle hook runner.
Implementations
Sourceimpl LifecycleRunner
impl LifecycleRunner
Sourcepub fn new() -> LifecycleRunner
pub fn new() -> LifecycleRunner
Creates an empty lifecycle runner.
Sourcepub fn hook<H>(self, hook: H) -> LifecycleRunnerwhere
H: LifecycleHook,
pub fn hook<H>(self, hook: H) -> LifecycleRunnerwhere
H: LifecycleHook,
Registers a lifecycle hook.
Sourcepub async fn startup(&self) -> Result<(), NidusError>
pub async fn startup(&self) -> Result<(), NidusError>
Runs startup hooks in registration order.
Sourcepub async fn shutdown(&self) -> Result<(), NidusError>
pub async fn shutdown(&self) -> Result<(), NidusError>
Runs shutdown hooks in reverse registration order.
Every hook is attempted even when an earlier hook fails. The first failure in shutdown order is returned after the remaining hooks run.